@@ -15,7 +15,7 @@ pub struct GridPosition {
 }
 
 #[derive(Debug)]
-/// Position or rather information for a stack page
+/// Position (or rather information) for a stack page
 /// inside a factory.
 pub struct StackPageInfo {
     /// The name of the [`gtk::StackPage`].
@@ -24,6 +24,15 @@ pub struct StackPageInfo {
     pub title: Option<String>,
 }
 
+#[derive(Debug)]
+/// Position (or rather information) for a tab page.
+pub struct TabPageInfo {
+    /// The tooltip of the tab page.
+    pub tooltip: Option<String>,
+    /// The title of the tab page.
+    pub title: Option<String>,
+}
+
 #[derive(Debug)]
 /// Position used for [`gtk::Fixed`].
 pub struct FixedPosition {
