@@ -161,13 +161,13 @@ where
     /// Use the sender to connect UI events and send messages back to modify the model.
     fn init_view(
         model: &ModelType,
-        parent_widgets: &ParentModel::Widgets,
+        _components: &ModelType::Components,
         sender: Sender<ModelType::Msg>,
     ) -> Self;
 
     /// Optional method to initialize components.
     /// This is only useful if you want to attach the widgets of a component to the widgets of this model.
-    fn connect_components(&self, _model: &ModelType, _components: &ModelType::Components) {}
+    fn connect_parent(&mut self, _parent_widgets: &ParentModel::Widgets) {}
 
     /// Return a clone of the root widget. This is typically a GTK4 widget.
     fn root_widget(&self) -> Self::Root;
@@ -252,21 +252,26 @@ where
 /// }
 ///
 /// impl Components<AppModel> for AppComponents {
-///     fn init_components(parent_model: &AppModel, parent_widgets: &AppWidgets, parent_sender: Sender<AppMsg>) -> Self {
+///     fn init_components(parent_model: &AppModel, parent_sender: Sender<AppMsg>) -> Self {
 ///         AppComponents {
-///             comp1: RelmComponent::with_new_thread(parent_model, parent_widgets, parent_sender.clone()),
-///             comp2: RelmComponent::new(parent_model, parent_widgets, parent_sender),
+///             comp1: RelmComponent::new(parent_model, parent_sender.clone()),
+///             comp2: RelmComponent::new(parent_model, parent_sender),
 ///         }
 ///     }
+///
+///     fn connect_parent(&mut self, parent_widgets: &AppWidgets) {
+///         self.comp1.connect_parent(parent_widgets);
+///         self.comp2.connect_parent(parent_widgets);
+///     }
 /// }
 /// ```
 pub trait Components<ParentModel: ?Sized + Model> {
     /// Initialize your components and workers inside this function.
-    fn init_components(
-        parent_model: &ParentModel,
-        parent_widget: &ParentModel::Widgets,
-        parent_sender: Sender<ParentModel::Msg>,
-    ) -> Self;
+    fn init_components(parent_model: &ParentModel, parent_sender: Sender<ParentModel::Msg>)
+        -> Self;
+
+    /// Connect the components to their parent components widgets (to set the parent window for example).
+    fn connect_parent(&mut self, _parent_widgets: &ParentModel::Widgets);
 }
 
 #[cfg(feature = "tokio-rt")]
